@@ -1,7 +1,5 @@
 
-
-
-### Copyright (C) 2001-2006 Deepayan Sarkar <Deepayan.Sarkar@R-project.org> 
+### Copyright (C) 2001-2009 Deepayan Sarkar <Deepayan.Sarkar@R-project.org> 
 ###
 ### This file is part of the lattice package for R.
 ### It is made available under the terms of the GNU General Public
@@ -139,10 +137,6 @@ updateList <- function(x, val)
 ## }
 
 
-
-
-
-
 ## Next 3 are convenience functions following those available in Trellis
 
 do.breaks  <- function(endpoints, nint)
@@ -155,7 +149,7 @@ do.breaks  <- function(endpoints, nint)
 Rows <- function(x, which)
 {
     for (i in seq_along(x)) x[[i]] <-
-        rep(x[[i]], length = max(which, length(which)))[which]
+        rep(x[[i]], length.out = max(which, length(which)))[which]
     x
 }
 
@@ -255,10 +249,10 @@ lsegments <-
     if (missing(y0)) y0 <- y2
     add.line <- trellis.par.get("add.line")
     ml <- max(length(x0), length(x1), length(y0), length(y1))
-    x0 <- rep(x0, length = ml)
-    x1 <- rep(x1, length = ml)
-    y0 <- rep(y0, length = ml)
-    y1 <- rep(y1, length = ml)
+    x0 <- rep(x0, length.out = ml)
+    x1 <- rep(x1, length.out = ml)
+    y0 <- rep(y0, length.out = ml)
+    y1 <- rep(y1, length.out = ml)
     grid.segments(x0 = x0, x1 = x1,
                   y0 = y0, y1 = y1,
                   gp =
@@ -321,10 +315,10 @@ larrows <-
     if (missing(y0)) y0 <- y2
     add.line <- trellis.par.get("add.line")
     ml <- max(length(x0), length(x1), length(y0), length(y1))
-    x0 <- rep(x0, length = ml)
-    x1 <- rep(x1, length = ml)
-    y0 <- rep(y0, length = ml)
-    y1 <- rep(y1, length = ml)
+    x0 <- rep(x0, length.out = ml)
+    x1 <- rep(x1, length.out = ml)
+    y0 <- rep(y0, length.out = ml)
+    y1 <- rep(y1, length.out = ml)
     gp <- gpar(col = col, lty=lty, lwd = lwd, alpha = alpha, fill = fill, ...)
     grid.segments(x0 = x0, x1 = x1,
                   y0 = y0, y1 = y1,
@@ -458,7 +452,7 @@ lplot.xy <-
              type = c("p", "l", "o", "b", "c", "s", "S", "h", "H"),
              pch = 1, lty = 1, col = 1, cex = 1, lwd = 1,
              font = 1, fontfamily = NULL, fontface = NULL,
-             col.line = col, alpha = 1, fill = NULL,
+             col.line = col, col.symbol = col, alpha = 1, fill = NULL,
              origin = 0,
              ...)
 {
@@ -475,7 +469,7 @@ lplot.xy <-
            p = {
                grid.points(x = x, y = y, 
                            gp =
-                           gpar(col = col, cex = cex, lwd = lwd,
+                           gpar(col = col.symbol, cex = cex, lwd = lwd,
                                 alpha = alpha, fill = fill,
                                 fontsize = fontsize.points,
                                 fontfamily = fontfamily,
@@ -493,7 +487,7 @@ lplot.xy <-
            b = {
                grid.points(x = x, y = y, 
                            gp =
-                           gpar(col = col, cex = cex, lwd = lwd,
+                           gpar(col = col.symbol, cex = cex, lwd = lwd,
                                 alpha = alpha, fill = fill,
                                 fontsize = fontsize.points,
                                 fontfamily = fontfamily,
@@ -606,3 +600,4 @@ lplot.xy <-
 }
 
 
+
